<?php
/**
 * Helper functions
 */

if ( ! function_exists( 'landed_pingback_header' ) ) :
	/**
	 * Add a pingback url auto-discovery header for singularly identifiable articles.
	 */
	function landed_pingback_header() {
		if ( is_singular() && pings_open() ) {
			echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
		}
	}

	add_action( 'wp_head', 'landed_pingback_header' );

endif;

if ( ! function_exists( 'landed_is_elementor_active' ) ) :
	/**
	 * Check if Elementor is active
	 */
	function landed_is_elementor_active() {
		return defined( 'ELEMENTOR_VERSION' );
	}
endif;

if ( ! function_exists( 'landed_is_tj_extras_active' ) ) :
	/**
	 * TJ Extras plugin activation checker.
	 */
	function landed_is_tj_extras_active() {
		return class_exists( 'TJ_Extras' ) ? true : false;
	}
endif;

if ( ! function_exists( 'landed_body_classes' ) ) :
	/**
	 * Adds classes to the body tag
	 */
	function landed_body_classes( $classes ) {

		// Vars
		$post_layout  = landed_post_layout();
		$container    = get_theme_mod( 'container_style', 'full-width' );
		$post_style   = get_theme_mod( 'post_style', 'grid' );

		// RTL
		if ( is_rtl() ) {
			$classes[] = 'rtl';
		}

		// Main class
		$classes[] = 'landed-theme';

		// Container style
		$classes[] = $container . '-container';

		// Sidebar enabled
		if ( 'left-sidebar' == $post_layout
			|| 'right-sidebar' == $post_layout ) {
			$classes[] = 'has-sidebar';
		}

		// Content layout
		if ( $post_layout ) {
			$classes[] = $post_layout;
		}

		// Has featured image.
		if ( is_singular() && has_post_thumbnail() ) {
			$classes[] = 'has-featured-image';
		}

		// Content style
		if ( is_home()
			|| is_category()
			|| is_tag()
			|| is_date()
			|| is_author() ) {
			$classes[] = 'post-style-' . $post_style;
		}

		// Return classes
		return $classes;

	}

	add_filter( 'body_class', 'landed_body_classes' );

endif;

if ( ! function_exists( 'landed_post_layout' ) ) :
	/**
	 * Returns correct post layout.
	 */
	function landed_post_layout() {

		// Define variables
		$class  = 'right-sidebar';
		$meta   = get_post_meta( get_the_ID(), 'tj_extras_post_layout', true );

		// Check meta first to override and return (prevents filters from overriding meta)
		if ( is_singular() && $meta ) {
			return $meta;
		}

		// Singular Page
		if ( is_page() ) {

			// Attachment
			if ( is_attachment() && wp_attachment_is_image() ) {
				$class = 'full-width';
			}

			// All other pages
			else {
				$class = get_theme_mod( 'page_layout', 'right-sidebar' );
			}

		}

		// Home
		elseif ( is_home()
			|| is_category()
			|| is_tag()
			|| is_date()
			|| is_author() ) {
			$class = get_theme_mod( 'post_layout', 'right-sidebar' );
		}

		// Singular Post
		elseif ( is_singular( 'post' ) ) {
			$class = get_theme_mod( 'post_layout', 'right-sidebar' );
		}

		// Library and Elementor template
		elseif ( is_singular( 'tj_library' )
    			|| is_singular( 'elementor_library' ) ) {
			$class = 'full-width';
		}

		// 404 page
		elseif ( is_404() ) {
			$class = 'full-width-narrow';
		}

		// All else
		else {
			$class = 'right-sidebar';
		}

		// Class should never be empty
		if ( empty( $class ) ) {
			$class = 'right-sidebar';
		}

		// Apply filters and return
		return apply_filters( 'landed_post_layout_class', $class );

	}

endif;

if ( ! function_exists( 'landed_get_sidebar' ) ) :
	/**
	 * Returns the correct sidebar region.
	 */
	function landed_get_sidebar( $sidebar = 'primary' ) {

		// Return the correct sidebar name & add useful hook
		$sidebar = apply_filters( 'landed_get_sidebar', $sidebar );

		// Check meta option after filter so it always overrides
		if ( $meta = get_post_meta( get_the_ID(), 'tj_extras_sidebar', true ) ) {
			$sidebar = $meta;
		}

		// Never show empty sidebar
		if ( ! is_active_sidebar( $sidebar ) ) {
			$sidebar = 'primary';
		}

		return $sidebar;
	}
endif;

if ( ! function_exists( 'landed_header' ) ) {
	/**
	 * Header template
	 */
	function landed_header() {

		$header = get_theme_mod( 'header_style', 'default' );
		$meta   = get_post_meta( get_the_ID(), 'tj_extras_custom_header_template', true );

		if ( is_singular() ) {

			if ( '' == $meta || '0' == $meta ) {
				get_template_part( 'partials/header/header' );
			} else {
				landed_get_custom_header();
			}

		} else {

			if ( 'default' == $header ) {
				get_template_part( 'partials/header/header' );
			} else {
				landed_get_custom_header();
			}

		}

	}

	add_action( 'landed_header', 'landed_header' );

}

if ( ! function_exists( 'landed_get_custom_header' ) ) :
	/**
	 * Get custom header template
	 */
	function landed_get_custom_header() {

		// Sets up empty variable
		$id = '';

		// Get the template ID
		$id = get_theme_mod( 'header_template', '0' );

		// Get the template ID from metabox
		if ( $meta = get_post_meta( get_the_ID(), 'tj_extras_custom_header_template', true ) ) {
			$id = $meta;
		}

		if ( $id ) {
			$args = array(
				'post_type' => 'tj_library',
				'p'         => $id
			);
			$loop = new WP_Query ($args );

			while ( $loop->have_posts() ) : $loop->the_post();
				global $post;
				the_content();
			endwhile;

			wp_reset_postdata();
		}

	}

endif;

if ( ! function_exists( 'landed_footer' ) ) {
	/**
	 * Header template
	 */
	function landed_footer() {

		$footer = get_theme_mod( 'footer_style', 'default' );
		$meta   = get_post_meta( get_the_ID(), 'tj_extras_custom_footer_template', true );

		if ( is_singular() ) {

			if ( '' == $meta || '0' == $meta ) {
				get_template_part( 'sidebar', 'footer' );
			} else {
				landed_get_custom_footer();
			}

		} else {

			if ( 'default' == $footer ) {
				get_template_part( 'sidebar', 'footer' );
			} else {
				landed_get_custom_footer();
			}

		}

	}

	add_action( 'landed_footer', 'landed_footer' );

}

if ( ! function_exists( 'landed_get_custom_footer' ) ) :
	/**
	 * Get custom header template
	 */
	function landed_get_custom_footer(){

		// Sets up empty variable
		$id = '';

		// Get the template ID
		$id = get_theme_mod( 'footer_template', '0' );

		// Get the template ID from metabox
		if ( $meta = get_post_meta( get_the_ID(), 'tj_extras_custom_footer_template', true ) ) {
			$id = $meta;
		}

		if ( $id ){
			$args = array(
				'post_type' => 'tj_library',
				'p'=> $id
			);
			$loop = new WP_Query ($args );

			while ( $loop->have_posts() ) : $loop->the_post();
				global $post;
				the_content();
			endwhile;

			wp_reset_postdata();
		}

	}

endif;

if ( ! function_exists( 'landed_post_classes' ) ) :
	/**
	 * Adds custom classes to the array of post classes.
	 */
	function landed_post_classes( $classes ) {

		// Replace hentry class with entry.
		$classes[] = 'entry';

		return $classes;
	}

	add_filter( 'post_class', 'landed_post_classes' );

endif;

if ( ! function_exists( 'landed_remove_hentry' ) ) :
	/**
	 * Remove 'hentry' from post_class()
	 */
	function landed_remove_hentry( $class ) {
		$class = array_diff( $class, array( 'hentry' ) );
		return $class;
	}

	add_filter( 'post_class', 'landed_remove_hentry' );

endif;

if ( ! function_exists( 'landed_excerpt_more' ) ) :
	/**
	 * Change the excerpt more string.
	 */
	function landed_excerpt_more( $more ) {
		return '&hellip;';
	}

	add_filter( 'excerpt_more', 'landed_excerpt_more' );

endif;

if ( ! function_exists( 'landed_custom_excerpt_length' ) ) :
	/**
	 * Filter the excerpt length.
	 */
	function landed_custom_excerpt_length( $length ) {

		// Sets default
		$length = 28;

		// Get the user settings
		$setting = get_theme_mod( 'excerpt', 28 );
		if ( 28 != $setting ) {
			$length = $setting;
		}

		return $length;
	}

	add_filter( 'excerpt_length', 'landed_custom_excerpt_length', 999 );

endif;

if ( ! function_exists( 'landed_extend_archive_title' ) ) :
	/**
	 * Extend archive title
	 */
	function landed_extend_archive_title( $title ) {
		if ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$title = single_tag_title( '', false );
		} elseif ( is_author() ) {
			$title = get_the_author();
		}
		return $title;
	}

	add_filter( 'get_the_archive_title', 'landed_extend_archive_title' );

endif;

if ( ! function_exists( 'landed_customize_tag_cloud' ) ) :
	/**
	 * Customize tag cloud widget
	 */
	function landed_customize_tag_cloud( $args ) {
		$args['largest']  = 13;
		$args['smallest'] = 13;
		$args['unit']     = 'px';
		$args['number']   = 20;
		return $args;
	}

	add_filter( 'widget_tag_cloud_args', 'landed_customize_tag_cloud' );

endif;
